@@ -423,6 +423,29 @@ xfce_gtk_toggle_tool_button_new_from_action_entry (const XfceGtkActionEntry *act
 
 
 
+/**
+ * xfce_gtk_menu_append_seperator:
+ * @menu : #GtkMenuShell on which the separator should be appended
+ *
+ * Convenience method do add separators, used to prevent code duplication
+ *
+ * Since: 4.16
+ *
+ * Deprecated: 4.19.1: Use xfce_gtk_menu_append_separator() instead.
+ **/
+void
+xfce_gtk_menu_append_seperator (GtkMenuShell *menu)
+{
+  GtkWidget *item;
+
+  g_return_if_fail (GTK_IS_MENU_SHELL (menu));
+
+  item = gtk_separator_menu_item_new ();
+  gtk_menu_shell_append (menu, item);
+}
+
+
+
 /**
  * xfce_gtk_menu_append_separator:
  * @menu : #GtkMenuShell on which the separator should be appended
